@@ -100,14 +100,7 @@ build_index(char *indexfile, char **vern)
 				nflds++;
 			if (strcmp(ent->flds[i], "-") == 0)
 				ent->flds[i] = p;
-			if (i == IDX_GRADE) {
-				if (strcmp(ent->flds[i], "exp") == 0)
-					ent->flds[i] = "Export";
-				else if (strcmp(ent->flds[i], "ffy") == 0)
-					ent->flds[i] = "Fortify";
-				else if (strcmp(ent->flds[i], "dom") == 0)
-					ent->flds[i] = "U.S. Domestic";
-			}
+
 			if (p < ent->raw + len)
 				p++;
 		}
@@ -119,7 +112,21 @@ build_index(char *indexfile, char **vern)
 		}
 
 		ent->size = atoi(ent->flds[IDX_SZ]);
-		ent->ismorphed = (strcmp(ent->flds[IDX_GRADE], "Fortify") == 0);
+		ent->grade = atoi(ent->flds[IDX_GRADE]);
+		ent->max_grade = atoi(ent->flds[IDX_MAX_GRADE]);
+
+		if (ent->grade == 0) {
+			ent->flds[IDX_GRADE] = "Export grade";
+		}
+		else if (ent->grade == ent->max_grade) {
+			ent->flds[IDX_GRADE] = "Fully Fortified";
+		}
+		else if (ent->grade == 1) {
+			ent->flds[IDX_GRADE] = "Fortified-SSL grade";
+		}
+		else {
+			ent->flds[IDX_GRADE] = "?? Unknown grade ??";
+		}
 
 		idx_sz++;
 		idx_ents = (index_entry_t **) _realloc((void *) idx_ents,
